@@ -11,10 +11,10 @@ use Games::EternalLands::Constants qw(%ClientCommandsByID $DEBUG_PACKETS $DEBUG_
 
 my $SERVER = "eternal-lands.network-studio.com";
 my $PORT   = "2001";
-my $ADMINS = "DarthCarter";
-my $OWNER  = "DarthCarter";
-my $USER   = 'DarthHunter';
-my $PASS   = 'CthrekGoru';
+my $ADMINS = undef;
+my $OWNER  = undef;
+my $USER   = undef;
+my $PASS   = undef;
 my $SLEEP  = 2;
 
 my $bot = Games::EternalLands::Bot->new(
